@@ -2,13 +2,12 @@ from .control import Control
 
 
 class Alarm(Control):
-    def get_cfg(self):
+    def get_cfg(self, page_x, page_y):
         # Overide get_cfg as Alarms don't have a config setting.
         return ""
 
-    def __init__(self, control_id, control_title="Title", body="Body", header="Header"):
+    def __init__(self, control_id, header="Header", body="Body"):
         super().__init__("ALM", control_id)
-        self.title = control_title
         self.body = body
         self.header = header
 
@@ -19,17 +18,17 @@ class Alarm(Control):
         pass
 
     @property
-    def body(self):
+    def body(self) -> str:
         return self._cfg["body"]
 
     @body.setter
-    def body(self, val):
+    def body(self, val: str):
         self._cfg["body"] = val
 
     @property
-    def header(self):
+    def header(self) -> str:
         return self._cfg["header"]
 
     @header.setter
-    def header(self, val):
+    def header(self, val: str):
         self._cfg["header"] = val
