@@ -1,3 +1,4 @@
+import logging
 from .event import Event
 from .enums import TitlePosition
 import json
@@ -11,12 +12,18 @@ class ControlPosition:
         self.width_ratio = width_ratio
         self.height_ratio = height_ratio
 
+    def __set_size(self, page_size_x, page_size_y):
+        logging.debug("Page X: {x}, Page Y: {y}".format(x=page_size_x, y=page_size_y))
+
 
 class Control:
-    def get_state(self):
-        return self.state_str
+    def get_state(self) -> str:
+        return ""
 
-    def get_cfg(self):
+    def get_cfg(self, page_size_x, page_size_y):
+        # logging.debug("Page size x: %s, y: %s", page_x, page_y)
+        if self.control_position:
+            self.control_position.__set_size(page_size_x, page_size_y)
         cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
@@ -31,7 +38,7 @@ class Control:
         self.control_id = control_id
         self.message_rx_event = Event()
         self.message_tx_event = Event()
-        self._state_str = "\t{}\t{}\n".format(self.msg_type, self.control_id)
+        self._state_str = "\t{{device_id}}\t{control_type}\t{control_id}\t".format(control_type=self.msg_type, control_id=self.control_id)
         self._control_position = None
         if control_position is not None:
             self.control_position = control_position
@@ -42,7 +49,6 @@ class Control:
 
     @state_str.setter
     def state_str(self, val):
-        self._state_str = val
         self.message_tx_event(val)
 
     # Use getter, setter properties to store the settings in the config dictionary
@@ -55,19 +61,19 @@ class Control:
         self._cfg["parentID"] = val
 
     @property
-    def control_id(self):
+    def control_id(self) -> str:
         return self._cfg["controlID"]
 
     @control_id.setter
-    def control_id(self, val):
+    def control_id(self, val: str):
         self._cfg["controlID"] = val
 
     @property
-    def title(self):
+    def title(self) -> str:
         return self._cfg["title"]
 
     @title.setter
-    def title(self, val):
+    def title(self, val: str):
         self._cfg["title"] = val
 
     @property
