@@ -1,4 +1,4 @@
-from .enums import Color, DialPosition, DialStyle, Precision, TitlePosition
+from .enums import Color, DialNumberPosition, DialStyle, Precision, TitlePosition
 from .control import Control
 
 
@@ -13,7 +13,7 @@ class Dial(Control):
         red_value=75.0,
         dial_fill_color=Color.RED,
         pointer_color=Color.BLUE,
-        number_position=DialPosition.LEFT,
+        number_position=DialNumberPosition.LEFT,
         show_min_max=False,
         style=DialStyle.STD,
         precision=Precision.OFF,
@@ -33,47 +33,49 @@ class Dial(Control):
         self.style = style
         self.precision = precision
         self.units = units
-        self.state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self._dial_value)
+
+    def get_state(self):
+        return self._state_str + "{}\n".format(self._dial_value)
 
     @property
-    def dial_value(self):
+    def dial_value(self) -> float:
         return self._dial_value
 
     @dial_value.setter
-    def dial_value(self, val):
+    def dial_value(self, val: float):
         self._dial_value = val
-        self.state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self._dial_value)
+        self.state_str = self._state_str + "{}\n".format(val)
 
     @property
-    def min(self):
+    def min(self) -> float:
         return self._cfg["min"]
 
     @min.setter
-    def min(self, val):
+    def min(self, val: float):
         self._cfg["min"] = val
 
     @property
-    def max(self):
+    def max(self) -> float:
         return self._cfg["max"]
 
     @max.setter
-    def max(self, val):
+    def max(self, val: float):
         self._cfg["max"] = val
 
     @property
-    def red_value(self):
+    def red_value(self) -> float:
         return self._cfg["redValue"]
 
     @red_value.setter
-    def red_value(self, val):
+    def red_value(self, val: float):
         self._cfg["redValue"] = val
 
     @property
-    def show_min_max(self):
+    def show_min_max(self) -> bool:
         return self._cfg["showMinMax"]
 
     @show_min_max.setter
-    def show_min_max(self, val):
+    def show_min_max(self, val: bool):
         self._cfg["showMinMax"] = val
 
     @property
@@ -81,7 +83,7 @@ class Dial(Control):
         return self._dial_fill_color
 
     @dial_fill_color.setter
-    def dial_fill_color(self, val):
+    def dial_fill_color(self, val: Color):
         self._dial_fill_color = val
         self._cfg["dialFillColor"] = str(val.value)
 
@@ -95,11 +97,11 @@ class Dial(Control):
         self._cfg["pointerColor"] = str(val.value)
 
     @property
-    def number_positions(self) -> DialPosition:
+    def number_positions(self) -> DialNumberPosition:
         return self._number_position
 
     @number_positions.setter
-    def number_positions(self, val: DialPosition):
+    def number_positions(self, val: DialNumberPosition):
         self._number_position = val
         self._cfg["numberPosition"] = val.value
 
@@ -122,9 +124,9 @@ class Dial(Control):
         self._cfg["precision"] = val.value
 
     @property
-    def units(self):
+    def units(self) -> str:
         return self._cfg["units"]
 
     @units.setter
-    def units(self, val):
+    def units(self, val: str):
         self._cfg["units"] = val
