@@ -1,10 +1,9 @@
 from .enums import TimeGraphLineType, Color, TitlePosition
 from .control import Control
-
+from .ring_buffer import RingBuffer
 import datetime
 import dateutil.parser
 
-
 class DataPoint:
     def __init__(self, data):
         self.timestamp = datetime.datetime.utcnow().replace(microsecond=0, tzinfo=datetime.timezone.utc)
@@ -17,39 +16,43 @@ class DataPoint:
 
 class TimeGraphLine:
     def __init__(
-        self, name="", line_type=TimeGraphLineType.LINE, color=Color.BLACK, transparency=1.0, max_data_points=60
+        self, name="", line_type=TimeGraphLineType.LINE, color=Color.BLACK, max_data_points=60, break_data=False
     ):
-        self.max_data_points = max_data_points
         self.name = name
         self.line_type = line_type
         self.color = color
-        self.transparency = transparency
-        self.data = []
+        self.break_data = break_data
+        self.data = RingBuffer(max_data_points)
 
     def get_line_data(self):
-        if not self.data:
+        if self.data.empty():
             return ""
-        data_str = "\t{l_name}\t{l_type}\t{l_color}\t{l_transparency}".format(
-            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value, l_transparency=self.transparency
+        data_str = "\t{l_name}\t{l_type}\t{l_color}".format(
+            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value
         )
-        for d in self.data:
+        for d in self.data.get():
             data_str += "\t" + d.to_string()
         data_str += "\n"
         return data_str
 
     def get_line_from_timestamp(self, timestamp):
-        if not self.data:
-            return ""
-        data_str = "\t{l_name}\t{l_type}\t{l_color}\t{l_transparency}".format(
-            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value, l_transparency=self.transparency
+        data_str = "\t{l_name}\t{l_type}\t{l_color}".format(
+            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value
         )
-
         dt = dateutil.parser.isoparse(timestamp)
-
-        for d in self.data:
+        first = True
+        valid_data = False
+        data_list = self.data.get()
+        for d in data_list:
             if d.timestamp > dt:
+                if first and self.break_data:
+                    data_str += "\t" + "{ts},{ldata}".format(ts=dt.isoformat(), ldata="b")
                 data_str += "\t" + d.to_string()
+                valid_data = True
+            first = False
         data_str += "\n"
+        if not valid_data:
+             data_str = ""
         return data_str
 
     def add_data_point(self, data_point):
@@ -59,48 +62,37 @@ class TimeGraphLine:
             data_point {str} -- A single data point
         """
         dp = DataPoint(data_point)
-        # now = datetime.datetime.utcnow().replace(microsecond=0, tzinfo=datetime.timezone.utc).isoformat()
-        # data_str = "{ts},{data}".format(ts=now, data=data_point)
-        if len(self.data) < self.max_data_points:
-            self.data.append(dp)
-            return
-        for i in range(len(self.data) - 1):
-            self.data[i] = self.data[i + 1]
-        self.data[-1] = dp
+        self.data.append(dp)
 
     def get_latest_data(self):
-        if not self.data:
+        if self.data.empty():
             return ""
-        data_str = "\t{l_name}\t{l_type}\t{l_color}\t{l_transparency}".format(
-            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value, l_transparency=self.transparency
+        data_str = "\t{l_name}\t{l_type}\t{l_color}".format(
+            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value
         )
-        data_str += "\t" + self.data[-1].to_string()
+        data_str += "\t" + self.data.get_latest().to_string()
         data_str += "\n"
         return data_str
 
 
 class TimeGraph(Control):
     def get_state(self):
-        state_str = ""
-        for key in self.line_dict.keys():
-            if self.line_dict[key].data:
-                state_str += self.get_state_str + key + self.line_dict[key].get_latest_data()
-        return state_str
+        return ""
 
     def __init__(
         self,
         control_id,
         title="A TimeGraph",
         title_position=TitlePosition.BOTTOM,
-        y_axis_label="",
-        y_axis_min="0.0",
+        y_axis_label="Y axis",
+        y_axis_min=0.0,
         y_axis_max=100.0,
         y_axis_num_bars=5,
         control_position=None,
     ):
         super().__init__("TGRPH", control_id, control_position=control_position, title_position=title_position)
         self.title = title
-        self.message_rx_event += self.__get_lines_from_timestamp
+        self.message_rx_event = self.__get_lines_from_timestamp
 
         self.y_axis_label = y_axis_label
         self.y_axis_min = y_axis_min
@@ -108,59 +100,58 @@ class TimeGraph(Control):
         self.y_axis_num_bars = y_axis_num_bars
 
         self.line_dict = {}
-        self.get_state_str = "\t{}\t{}\t".format(self.msg_type, self.control_id)
 
-    def add_line(self, line_id, gline):
+    def add_line(self, line_id: str, gline: TimeGraphLine):
         self.line_dict[line_id] = gline
 
     def send_graph(self):
         state_str = ""
         for key in self.line_dict.keys():
-            state_str += self.get_state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._state_str + key + self.line_dict[key].get_line_data()
         self.state_str = state_str
 
     def __get_lines_from_timestamp(self, msg):
         state_str = ""
         for key in self.line_dict.keys():
             if self.line_dict[key].data:
-                state_str += self.get_state_str + key + self.line_dict[key].get_line_from_timestamp(msg[3])
+                state_str += self._state_str  + key + self.line_dict[key].get_line_from_timestamp(msg[3])
         self.state_str = state_str
 
     def send_data(self):
         state_str = ""
         for key in self.line_dict.keys():
             if self.line_dict[key].data:
-                state_str += self.get_state_str + key + self.line_dict[key].get_latest_data()
+                state_str += self._state_str + key + self.line_dict[key].get_latest_data()
         self.state_str = state_str
 
     @property
-    def y_axis_label(self):
+    def y_axis_label(self) -> str:
         return self._cfg["yAxisLabel"]
 
     @y_axis_label.setter
-    def y_axis_label(self, val):
+    def y_axis_label(self, val: str):
         self._cfg["yAxisLabel"] = val
 
     @property
-    def y_axis_min(self):
+    def y_axis_min(self) -> float:
         return self._cfg["yAxisMin"]
 
     @y_axis_min.setter
-    def y_axis_min(self, val):
+    def y_axis_min(self, val: float):
         self._cfg["yAxisMin"] = val
 
     @property
-    def y_axis_max(self):
+    def y_axis_max(self) -> float:
         return self._cfg["yAxisMax"]
 
     @y_axis_max.setter
-    def y_axis_max(self, val):
+    def y_axis_max(self, val: float):
         self._cfg["yAxisMax"] = val
 
     @property
-    def y_axis_num_bars(self):
+    def y_axis_num_bars(self) -> int:
         return self._cfg["yAxisNumBars"]
 
     @y_axis_num_bars.setter
-    def y_axis_num_bars(self, val):
+    def y_axis_num_bars(self, val: int):
         self._cfg["yAxisNumBars"] = val
